@@ -24,7 +24,11 @@ from openai.types.beta import Thread
 from openai.types.beta.threads import message_create_params, Message
 
 from dotenv import load_dotenv
-from openai.types.beta.vector_stores import VectorStoreFile
+
+try:
+    from openai.types.beta.vector_stores import VectorStoreObject
+except ImportError:
+    from openai.types.vector_store import VectorStore as VectorStoreObject
 
 from astra_assistants import OpenAIWithDefaultKey, AsyncOpenAIWithDefaultKey
 
@@ -776,4 +780,4 @@ def patch(client: Union[OpenAI, AsyncOpenAI]):
     client.copy = MethodType(enhance_copy_method(client.copy), client.copy)
     client.with_options = client.copy
 
-    return client
\ No newline at end of file
+    return client
